pub fn detect_format(path: &str) -> Result<DocumentFormat, ParseError>Expand description
Infer the format from a file path per the spec 4 extensions.
pub fn detect_format(path: &str) -> Result<DocumentFormat, ParseError>Infer the format from a file path per the spec 4 extensions.