#[repr(i32)]pub enum Accumulation {
Unspecified = 0,
Instantaneous = 1,
Register = 2,
Interval = 3,
Lifetime = 4,
Session = 5,
Daily = 6,
Monthly = 7,
}Expand description
22.6 Accumulation kind.
Variants
Unspecified = 0
Instantaneous = 1
Register = 2
Interval = 3
Lifetime = 4
Session = 5
Daily = 6
Monthly = 7
Implementations
Sourceimpl Accumulation
impl Accumulation
Sourceimpl Accumulation
impl Accumulation
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.