#[repr(i32)]pub enum AddressSpace {
Unspecified = 0,
Coil = 1,
DiscreteInput = 2,
InputRegister = 3,
HoldingRegister = 4,
}Expand description
7 Address spaces. 0-based offsets within each space.
Variants
Implementations
Sourceimpl AddressSpace
impl AddressSpace
Sourceimpl AddressSpace
impl AddressSpace
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.