#[repr(i32)]pub enum ByteOrder {
Unspecified = 0,
BigEndian = 1,
LittleEndian = 2,
}Expand description
9.1 Byte order within a 16-bit word. Default when omitted: BIG_ENDIAN (spec/adr/0004).
Variants
Implementations
Sourceimpl ByteOrder
impl ByteOrder
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.