#[repr(i32)]pub enum ConditionOp {
Unspecified = 0,
Eq = 1,
Ne = 2,
Mask = 3,
Range = 4,
}Expand description
11.7 Comparison operator for a poll-step exit condition.
Variants
Unspecified = 0
Eq = 1
raw == value
Ne = 2
raw != value
Mask = 3
(raw & mask) == value
Range = 4
min <= raw <= max
Implementations
Sourceimpl ConditionOp
impl ConditionOp
Sourceimpl ConditionOp
impl ConditionOp
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.