#[repr(i32)]pub enum PhaseRef {
Unspecified = 0,
PhaseNone = 1,
L1 = 2,
L2 = 3,
L3 = 4,
N = 5,
L1N = 6,
L2N = 7,
L3N = 8,
L1L2 = 9,
L2L3 = 10,
L3L1 = 11,
}Expand description
22.3 Phase / reference. Wire form mirrors OCPP (L1-N, L1-L2, …).
Variants
Unspecified = 0
PhaseNone = 1
L1 = 2
L2 = 3
L3 = 4
N = 5
L1N = 6
L2N = 7
L3N = 8
L1L2 = 9
L2L3 = 10
L3L1 = 11
Implementations
Sourceimpl PhaseRef
impl PhaseRef
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.