#[repr(i32)]pub enum ScaleMode {
Unspecified = 0,
Pow10 = 1,
Multiply = 2,
}Expand description
10.4 Mode for register-referenced (dynamic) scaling.
Variants
Unspecified = 0
Pow10 = 1
value = raw * 10^ref (SunSpec SF)
Multiply = 2
value = raw * ref / denominator
Implementations
Sourceimpl ScaleMode
impl ScaleMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.