#[repr(i32)]pub enum WordOrder {
Unspecified = 0,
WordBigEndian = 1,
WordLittleEndian = 2,
}Expand description
9.2 Word order for multi-word values. Default when omitted: WORD_BIG_ENDIAN.
Variants
Implementations
Sourceimpl WordOrder
impl WordOrder
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.