#[repr(i32)]pub enum WriteBehavior {
Unspecified = 0,
Direct = 1,
Momentary = 2,
Latch = 3,
Masked = 4,
CommandTrigger = 5,
}Expand description
11.3 Write behavior for writable / command points.
Variants
Implementations
Sourceimpl WriteBehavior
impl WriteBehavior
Sourceimpl WriteBehavior
impl WriteBehavior
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.