pub struct CommandParam {
pub field: String,
pub storage_type: i32,
pub value_type: Option<ValueType>,
pub mapping: Option<Mapping>,
pub required: bool,
}Expand description
11.7 Caller-supplied input to a command, with its own wire mapping.
required params MUST be written by at least one WriteStep (MDE504).
Fields
field: Stringstorage_type: i32value_type: Option<ValueType>mapping: Option<Mapping>required: boolImplementations
Sourceimpl CommandParam
impl CommandParam
Sourcepub fn storage_type(&self) -> StorageType
pub fn storage_type(&self) -> StorageType
Returns the enum value of storage_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_storage_type(&mut self, value: StorageType)
pub fn set_storage_type(&mut self, value: StorageType)
Sets storage_type to the provided enum value.