pub struct Condition {
pub op: i32,
pub value: i64,
pub mask: i64,
pub min: i64,
pub max: i64,
}Expand description
11.7 Exit condition evaluated against the raw (pre-transform) integer value of the polled point. Structural validity per op: MDE507.
Fields
op: i32value: i64EQ / NE / MASK
mask: i64MASK; MUST NOT be zero
min: i64RANGE
max: i64RANGE; MUST be >= min
Implementations
Sourceimpl Condition
impl Condition
Sourcepub fn op(&self) -> ConditionOp
pub fn op(&self) -> ConditionOp
Returns the enum value of op, or the default if the field is set to an invalid enum value.
Sourcepub fn set_op(&mut self, value: ConditionOp)
pub fn set_op(&mut self, value: ConditionOp)
Sets op to the provided enum value.