pub struct DateTimeSpec {
pub encoding: i32,
pub width: i32,
}Expand description
8.5 Date/time value encoding spec.
Fields
encoding: i32width: i32U32 / U64 for epoch encodings
Implementations
Sourceimpl DateTimeSpec
impl DateTimeSpec
Sourcepub fn encoding(&self) -> DateTimeEncoding
pub fn encoding(&self) -> DateTimeEncoding
Returns the enum value of encoding, or the default if the field is set to an invalid enum value.
Sourcepub fn set_encoding(&mut self, value: DateTimeEncoding)
pub fn set_encoding(&mut self, value: DateTimeEncoding)
Sets encoding to the provided enum value.
Sourcepub fn width(&self) -> StorageType
pub fn width(&self) -> StorageType
Returns the enum value of width, or the default if the field is set to an invalid enum value.
Sourcepub fn set_width(&mut self, value: StorageType)
pub fn set_width(&mut self, value: StorageType)
Sets width to the provided enum value.