pub struct DeviceVariant {
pub variant_id: String,
pub name: String,
pub base_device_id: String,
pub overrides: Vec<PointOverride>,
pub additions: Vec<Point>,
pub removals: Vec<String>,
}Expand description
18 Firmware/hardware/regional/option variant of a base profile.
Fields
variant_id: Stringname: Stringbase_device_id: Stringoverrides: Vec<PointOverride>additions: Vec<Point>removals: Vec<String>Trait Implementations
Sourceimpl Clone for DeviceVariant
impl Clone for DeviceVariant
Sourcefn clone(&self) -> DeviceVariant
fn clone(&self) -> DeviceVariant
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceVariant
impl Debug for DeviceVariant
Sourceimpl Default for DeviceVariant
impl Default for DeviceVariant
impl<'de> Deserialize<'de> for DeviceVariant
impl<'de> Deserialize<'de> for DeviceVariant
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for DeviceVariant
impl Message for DeviceVariant
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for DeviceVariant
impl PartialEq for DeviceVariant
Sourcefn eq(&self, other: &DeviceVariant) -> bool
fn eq(&self, other: &DeviceVariant) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Serialize for DeviceVariant
impl Serialize for DeviceVariant
impl StructuralPartialEq for DeviceVariant