pub struct Discovery {
pub kind: i32,
pub anchor_candidates: Vec<u32>,
pub model_id: u32,
}Fields
kind: i32anchor_candidates: Vec<u32>e.g. 0, 40000, 50000
model_id: u32SunSpec model to resolve this block to
Implementations
Sourceimpl Discovery
impl Discovery
Sourcepub fn kind(&self) -> DiscoveryKind
pub fn kind(&self) -> DiscoveryKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: DiscoveryKind)
pub fn set_kind(&mut self, value: DiscoveryKind)
Sets kind to the provided enum value.