pub struct MeasurandRef {
pub measurand_id: String,
pub base_quantity: String,
pub direction: i32,
pub phase_ref: i32,
pub aggregation: i32,
pub location: i32,
pub accumulation: i32,
}Expand description
22 / 25 Reference to a measurand from a point. Either resolve measurand_id
or supply an inline semantic tuple (or both, with the tuple as override).
Fields
measurand_id: Stringbase_quantity: StringOptional inline semantic tuple — avoids defining every combination as a separate measurand id.
direction: i32phase_ref: i32aggregation: i32location: i32accumulation: i32Implementations
Sourceimpl MeasurandRef
impl MeasurandRef
Sourcepub fn direction(&self) -> Direction
pub fn direction(&self) -> Direction
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: Direction)
pub fn set_direction(&mut self, value: Direction)
Sets direction to the provided enum value.
Sourcepub fn phase_ref(&self) -> PhaseRef
pub fn phase_ref(&self) -> PhaseRef
Returns the enum value of phase_ref, or the default if the field is set to an invalid enum value.
Sourcepub fn set_phase_ref(&mut self, value: PhaseRef)
pub fn set_phase_ref(&mut self, value: PhaseRef)
Sets phase_ref to the provided enum value.
Sourcepub fn aggregation(&self) -> Aggregation
pub fn aggregation(&self) -> Aggregation
Returns the enum value of aggregation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_aggregation(&mut self, value: Aggregation)
pub fn set_aggregation(&mut self, value: Aggregation)
Sets aggregation to the provided enum value.
Sourcepub fn location(&self) -> MeasurementLocation
pub fn location(&self) -> MeasurementLocation
Returns the enum value of location, or the default if the field is set to an invalid enum value.
Sourcepub fn set_location(&mut self, value: MeasurementLocation)
pub fn set_location(&mut self, value: MeasurementLocation)
Sets location to the provided enum value.
Sourcepub fn accumulation(&self) -> Accumulation
pub fn accumulation(&self) -> Accumulation
Returns the enum value of accumulation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_accumulation(&mut self, value: Accumulation)
pub fn set_accumulation(&mut self, value: Accumulation)
Sets accumulation to the provided enum value.