pub struct ModDefDocument {
pub doc_id: String,
pub name: String,
pub version: String,
pub imports: Vec<Import>,
pub enums: Vec<EnumType>,
pub structs: Vec<StructType>,
pub measurands: Vec<MeasurandDefinition>,
pub measurand_aliases: Vec<MeasurandAlias>,
pub devices: Vec<DeviceProfile>,
}Expand description
6 A complete ModDef document.
Fields
doc_id: Stringname: Stringversion: Stringimports: Vec<Import>enums: Vec<EnumType>structs: Vec<StructType>measurands: Vec<MeasurandDefinition>measurand_aliases: Vec<MeasurandAlias>devices: Vec<DeviceProfile>Trait Implementations
Sourceimpl Clone for ModDefDocument
impl Clone for ModDefDocument
Sourcefn clone(&self) -> ModDefDocument
fn clone(&self) -> ModDefDocument
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModDefDocument
impl Debug for ModDefDocument
Sourceimpl Default for ModDefDocument
impl Default for ModDefDocument
impl<'de> Deserialize<'de> for ModDefDocument
impl<'de> Deserialize<'de> for ModDefDocument
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for ModDefDocument
impl Message for ModDefDocument
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ModDefDocument
impl PartialEq for ModDefDocument
Sourcefn eq(&self, other: &ModDefDocument) -> bool
fn eq(&self, other: &ModDefDocument) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Serialize for ModDefDocument
impl Serialize for ModDefDocument
impl StructuralPartialEq for ModDefDocument