pub struct RegisterBlock {
pub block_id: String,
pub name: String,
pub space: i32,
pub start_offset: u32,
pub length_words: u32,
pub overlay: bool,
pub discovery: Option<Discovery>,
pub points: Vec<Point>,
}Expand description
17 A group of related points over a contiguous (or discovered) range.
Fields
block_id: Stringname: Stringspace: i32start_offset: u32length_words: u32overlay: bool17 — allow overlap with other blocks (MDE301)
discovery: Option<Discovery>v0.4 7.3 — SunSpec/dynamic addressing
points: Vec<Point>Implementations
Sourceimpl RegisterBlock
impl RegisterBlock
Sourcepub fn space(&self) -> AddressSpace
pub fn space(&self) -> AddressSpace
Returns the enum value of space, or the default if the field is set to an invalid enum value.
Sourcepub fn set_space(&mut self, value: AddressSpace)
pub fn set_space(&mut self, value: AddressSpace)
Sets space to the provided enum value.