pub struct StringEncoding {
pub charset: i32,
pub padding: i32,
pub termination: i32,
}Expand description
15 String encoding details. Register length comes from Mapping.length_words.
Fields
charset: i32padding: i32termination: i32Implementations
Sourceimpl StringEncoding
impl StringEncoding
Sourcepub fn charset(&self) -> Charset
pub fn charset(&self) -> Charset
Returns the enum value of charset, or the default if the field is set to an invalid enum value.
Sourcepub fn set_charset(&mut self, value: Charset)
pub fn set_charset(&mut self, value: Charset)
Sets charset to the provided enum value.
Sourcepub fn padding(&self) -> Padding
pub fn padding(&self) -> Padding
Returns the enum value of padding, or the default if the field is set to an invalid enum value.
Sourcepub fn set_padding(&mut self, value: Padding)
pub fn set_padding(&mut self, value: Padding)
Sets padding to the provided enum value.
Sourcepub fn termination(&self) -> Termination
pub fn termination(&self) -> Termination
Returns the enum value of termination, or the default if the field is set to an invalid enum value.
Sourcepub fn set_termination(&mut self, value: Termination)
pub fn set_termination(&mut self, value: Termination)
Sets termination to the provided enum value.