pub struct WriteSemantics {
pub behavior: i32,
pub confirmation_point: String,
pub requires_enable_point: String,
pub constraints: Option<WriteConstraints>,
}Expand description
11.2/11.3/11.4 Write semantics for writable / command points.
Fields
behavior: i32confirmation_point: Stringpoint_id read back to confirm
requires_enable_point: Stringpoint_id that must be enabled first
constraints: Option<WriteConstraints>Implementations
Sourceimpl WriteSemantics
impl WriteSemantics
Sourcepub fn behavior(&self) -> WriteBehavior
pub fn behavior(&self) -> WriteBehavior
Returns the enum value of behavior, or the default if the field is set to an invalid enum value.
Sourcepub fn set_behavior(&mut self, value: WriteBehavior)
pub fn set_behavior(&mut self, value: WriteBehavior)
Sets behavior to the provided enum value.