pub struct Mapping {
pub space: i32,
pub offset: u32,
pub length_words: u32,
pub bit_index: u32,
pub byte_order: i32,
pub word_order: i32,
pub sign_magnitude: bool,
pub stride_words: u32,
pub model_relative_offset: u32,
pub composed: Option<Box<ComposedMapping>>,
pub allowed_function_codes: Vec<u32>,
pub string_encoding: Option<StringEncoding>,
}Expand description
9, 14, 14.1 Physical location and encoding of a point’s raw data.
Fields
space: i32offset: u32length_words: u32bit_index: u32byte_order: i32word_order: i32sign_magnitude: boolv0.4 — sign-magnitude instead of two’s complement
stride_words: u32v0.4 — repeating-array element stride (14.1)
model_relative_offset: u32v0.4 — offset within a discovered model (7.3)
composed: Option<Box<ComposedMapping>>allowed_function_codes: Vec<u32>7.2
string_encoding: Option<StringEncoding>15
Implementations
Sourceimpl Mapping
impl Mapping
Sourcepub fn space(&self) -> AddressSpace
pub fn space(&self) -> AddressSpace
Returns the enum value of space, or the default if the field is set to an invalid enum value.
Sourcepub fn set_space(&mut self, value: AddressSpace)
pub fn set_space(&mut self, value: AddressSpace)
Sets space to the provided enum value.
Sourcepub fn byte_order(&self) -> ByteOrder
pub fn byte_order(&self) -> ByteOrder
Returns the enum value of byte_order, or the default if the field is set to an invalid enum value.
Sourcepub fn set_byte_order(&mut self, value: ByteOrder)
pub fn set_byte_order(&mut self, value: ByteOrder)
Sets byte_order to the provided enum value.
Sourcepub fn word_order(&self) -> WordOrder
pub fn word_order(&self) -> WordOrder
Returns the enum value of word_order, or the default if the field is set to an invalid enum value.
Sourcepub fn set_word_order(&mut self, value: WordOrder)
pub fn set_word_order(&mut self, value: WordOrder)
Sets word_order to the provided enum value.